# -*- coding: utf-8 -*-

import sys

import click

from . import aws_key_formatter
from .__version__ import __version__


@click.command()
@click.version_option(version=__version__, prog_name='aws-key-formatter')
@click.option('-p', '--profile', default='default', show_default=True, help='AWS CLI Profile name')
@click.option('--token/--no-token', ' -t/', default=False, show_default=True, help='Include AWS Session Token?')
def main(profile: str, token: bool):
    """Console script for aws_key_formatter."""
    # TODO: Have the aws_key_formatter function return the string,
    # then have this function do the `click.echo` to output it.
    aws_key_formatter.main(profile, token)

    return 0


if __name__ == "__main__":
    sys.exit(main())



# -*- coding: utf-8 -*-

import os
from codecs import open

from setuptools import find_packages, setup


NAME = 'aws-key-formatter'
DESCRIPTION = ''
AUTHOR = 'Kelton Karboviak'
EMAIL = 'kelton.karboviak@gmail.com'
URL = 'https://github.com/KeltonKarboviak/aws-key-formatter'

REQUIRED = [
    'boto3>=1.9,<2.0',
    'click>=7.0,<8.0',
]

EXTRAS = {}

here = os.path.abspath(os.path.dirname(__file__))
src_dir = os.path.join(here, 'src')


def read(filename):
    with open(os.path.join(here, filename), 'r', encoding='utf-8') as fp:
        return fp.read()


long_description = read('README.md')
changelog = read('CHANGELOG.md')
license_terms = read('LICENSE.md')


about = {}
project_slug = NAME.lower().replace("-", "_").replace(" ", "_")
exec(read(os.path.join(src_dir, project_slug, '__version__.py')), about)


setup(
    name=NAME,
    version=about['__version__'],
    author=AUTHOR,
    author_email=EMAIL,
    description=DESCRIPTION,
    long_description=long_description + '\n\n' + changelog + '\n\n' + license_terms,
    long_description_content_type='text/markdown',
    url=URL,
    packages=find_packages('src'),
    package_dir={'': 'src'},
    entry_points={
        'console_scripts': ['aws-key-formatter=aws_key_formatter.cli:main']
    },
    install_requires=REQUIRED,
    extras_require=EXTRAS,
    include_package_data=True,
    license='MIT',
    classifiers=[
        # Trove classifiers
        # Full list: https://pypi.python.org/pypi?%3Aaction=list_classifiers
        'License :: OSI Approved :: MIT License',
        'Intended Audience :: Developers',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        # 'Programming Language :: Python :: 3.8',
        'Operating System :: OS Independent',
    ],
)



# -*- coding: utf-8 -*-

"""Main module."""

import argparse
import textwrap

import boto3


def _format_credentials(creds, include_token: bool):
    formatted_str = textwrap.dedent(
        f"""\
        ACCESS_KEY_ID '{creds.access_key}'
        SECRET_ACCESS_KEY '{creds.secret_key}'
        {f"SESSION_TOKEN '{creds.token}'" if include_token else ""}
        """
    ).strip()

    return formatted_str


def _get_creds_from_session(session):
    return session.get_credentials().get_frozen_credentials()


def main(aws_profile: str, include_token: bool):
    session = boto3.Session(profile_name=aws_profile)
    creds = _get_creds_from_session(session)

    formatted_str = _format_credentials(creds, include_token)

    print(formatted_str)


if __name__ == '__main__':
    parser = argparse.ArgumentParser()
    parser.add_argument(
        '--profile', '-p', default='default', help='AWS CLI Profile name'
    )
    parser.add_argument(
        '--include_token', '-t', action='store_true', help='Include AWS Session Token?'
    )

    args = parser.parse_args()

    main(args.profile, args.include_token)
